# -*- coding: utf-8 -*-

import os
import subprocess
import sys

# May fail when imported while no Tkinter is available, so ignore:
try:
    import easygui
except:
    pass


def remove_squish_paths_and_run_again(squish_prefix):
    """Squish's Python may not have Tkinter, so remove Squish's
    path entries from the PATH environment variable, and then run
    this complete command again as another process. That way any
    other Python installation (if any) should be used to run this
    script. (And "proper" Python installations typically have
    Tkinter.)"""

    # Get PATH
    path_env = os.environ["PATH"]

    # Split PATH to get paths
    paths = path_env.split(os.pathsep)

    # Loop over paths and concatenate the ones that do not start with SQUISH_PREFIX
    new_path = ""
    for p in paths:
        if not p.startswith(squish_prefix):
            new_path += os.pathsep + p

    # Remove os.path.separator prefix
    new_path = new_path[len(os.pathsep):]

    # Put PATH
    os.putenv("PATH", new_path)

    # Execute original command
    args = sys.argv
    args.insert(0, "python")
    proc = subprocess.Popen(args=args, shell=True)
    proc.communicate()
    sys.exit(proc.returncode)


def choicebox():
    args = sys.argv[1:]
    msg = args[0]
    args = args[1:]
    title = args[0]
    args = args[1:]
    choice = easygui.choicebox(msg=msg, title=title, choices=args)
    if choice:
        print(choice)


def has_tkinter():
    """Squish's included Python interpreter may not have Tkinter,
    allow to check for this"""

    try:
        import Tkinter
        return True
    except:
        return False


if __name__ == "__main__":
    n = "SQUISH_PREFIX"
    if has_tkinter() or not n in os.environ:
        choicebox()
    else:
        squish_prefix = os.environ[n]
        os.unsetenv(n)
        remove_squish_paths_and_run_again(squish_prefix)
